@@ -9,8 +9,8 @@
 
 extern void _continuous_aggs_cache_inval_init(void);
 extern void _continuous_aggs_cache_inval_fini(void);
-extern void execute_cagg_trigger(int32 hypertable_id, Relation chunk_rel, HeapTuple chunk_tuple,
-								 HeapTuple chunk_newtuple, bool update);
+extern void continuous_agg_invalidate_range(int32 hypertable_id, Oid chunk_relid, int64 start,
+											int64 end);
 extern void continuous_agg_dml_invalidate(int32 hypertable_id, Relation chunk_rel,
 										  HeapTuple chunk_tuple, HeapTuple chunk_newtuple,
 										  bool update);
